@@ -49,7 +49,8 @@ class mysqlUtil:
             # print(df)
             row1=pd.DataFrame({'filename':filename,'url':url,'stud':stud}, index=[1])
             # print(row1)
-            df=df.append(row1,ignore_index=True)
+            # df=df.append(row1,ignore_index=True)
+            df = pd.concat([df, row1], ignore_index=True)  # append过时，改用concat
             # print(df)
             df.to_sql("sftp_files", self.engine, if_exists='append', index=False)  # 'sftp_files'
 
